@@ -1,6 +1,6 @@
 package Code::TidyAll::Plugin::PerlCritic;
 BEGIN {
-  $Code::TidyAll::Plugin::PerlCritic::VERSION = '0.02';
+  $Code::TidyAll::Plugin::PerlCritic::VERSION = '0.04';
 }
 use Perl::Critic::Command qw();
 use Capture::Tiny qw(capture_merged);
@@ -21,7 +21,7 @@ sub validate_file {
     #
     local @ARGV = @argv;
     my $output = capture_merged { Perl::Critic::Command::run() };
-    die $output if $output !~ /^.* source OK\n/;
+    die "$output\n" if $output !~ /^.* source OK\n/;
 }
 
 1;
@@ -36,7 +36,7 @@ Code::TidyAll::Plugin::PerlCritic - use perlcritic with tidyall
 
 =head1 VERSION
 
-version 0.02
+version 0.04
 
 =head1 SYNOPSIS
 
