@@ -1,6 +1,6 @@
 package Code::TidyAll::Plugin::PerlTidy;
 BEGIN {
-  $Code::TidyAll::Plugin::PerlTidy::VERSION = '0.02';
+  $Code::TidyAll::Plugin::PerlTidy::VERSION = '0.04';
 }
 use Perl::Tidy;
 use Hash::MoreUtils qw(slice_exists);
@@ -8,7 +8,7 @@ use strict;
 use warnings;
 use base qw(Code::TidyAll::Plugin);
 
-sub process_source {
+sub transform_source {
     my ( $self, $source ) = @_;
     my $options = $self->options;
 
@@ -40,7 +40,7 @@ Code::TidyAll::Plugin::PerlTidy - use perltidy with tidyall
 
 =head1 VERSION
 
-version 0.02
+version 0.04
 
 =head1 SYNOPSIS
 
